VfsError

Enum VfsError 

#[non_exhaustive]
pub enum VfsError {
Show 14 variants Snapshot(SnapshotError), Store(BlobStoreError), Path(VPathError), NotFound { path: VPath, }, AlreadyExists { path: VPath, }, NotDirectory { path: VPath, actual: NodeKind, }, NotFile { path: VPath, actual: NodeKind, }, NotSymlink { path: VPath, actual: NodeKind, }, IsDirectory { path: VPath, }, DirectoryNotEmpty { path: VPath, }, RootMutation, InvalidRename { from: VPath, to: VPath, }, RenameTypeMismatch { from: VPath, to: VPath, }, InvalidCanonicalDiff { path: Option<VPath>, reason: &'static str, },
}
Virtual filesystem operation failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Snapshot(SnapshotError)

Snapshot access or lazy capture failed.



Store(BlobStoreError)

Immutable blob storage failed.



Path(VPathError)

A virtual path was invalid during an internal rebase.



NotFound

The requested path does not exist in virtual state.

Fields

path: VPath

Missing path.



AlreadyExists

The target already exists.

Fields

path: VPath

Existing path.



NotDirectory

A directory operation targeted another node kind.

Fields

path: VPath

Requested path.

actual: NodeKind

Actual kind.



NotFile

A regular-file operation targeted another node kind.

Fields

path: VPath

Requested path.

actual: NodeKind

Actual kind.

A symlink operation targeted another node kind.

Fields

path: VPath

Requested path.

actual: NodeKind

Actual kind.



IsDirectory

A file-only deletion targeted a directory.

Fields

path: VPath

Directory path.



DirectoryNotEmpty

A non-empty directory cannot be removed/replaced.

Fields

path: VPath

Non-empty directory.



RootMutation

The immutable virtual root cannot be mutated.



InvalidRename

Source and destination subtrees overlap.

Fields

from: VPath

Source root.

to: VPath

Destination root.



RenameTypeMismatch

Rename source and destination kinds are incompatible.

Fields

from: VPath

Source path.

to: VPath

Destination path.



InvalidCanonicalDiff

A decoded durable artifact violated canonical diff invariants.

Fields

path: Option<VPath>

Affected path, when the violation is path-specific.

reason: &'static str

Stable validation reason.