pub struct RiskMetrics {
pub touched_paths: usize,
pub created_paths: usize,
pub modified_paths: usize,
pub deleted_paths: usize,
pub renamed_paths: usize,
pub changed_bytes: u64,
pub delete_ratio_bps: u16,
pub executable_changes: usize,
pub symlink_changes: usize,
}Expand description
Exact bounded metrics used for a deterministic policy decision.
Fields
touched_paths: usizeAll canonical changed paths.
created_paths: usizeNewly created paths.
modified_paths: usizeContent or metadata modifications.
deleted_paths: usizeDeleted paths, including recursive-delete closure.
renamed_paths: usizeSemantic rename operations observed in the ledger.
changed_bytes: u64Sum of before and after bytes represented by changed non-directory nodes.
delete_ratio_bps: u16Deletions divided by user-visible base nodes, in basis points.
executable_changes: usizeChanges that add/remove an executable mode bit.
symlink_changes: usizeChanges involving an opaque symbolic link.
Implementations
Sourceimpl RiskMetrics
impl RiskMetrics
Sourcepub fn from_evidence(
diff: &CanonicalDiff,
effects: &[EffectEvent],
base_node_count: usize,
) -> RiskMetrics
pub fn from_evidence( diff: &CanonicalDiff, effects: &[EffectEvent], base_node_count: usize, ) -> RiskMetrics
Derive the exact metrics used by policy from bounded transaction evidence.