pub struct SnapshotBuilder { /* private fields */ }Expand description
Builder for one immutable snapshot manifest.
Implementations
Sourceimpl SnapshotBuilder
impl SnapshotBuilder
Sourcepub fn new(store: BlobStore) -> SnapshotBuilder
pub fn new(store: BlobStore) -> SnapshotBuilder
Start a snapshot containing only the virtual root directory.
Sourcepub fn with_root_stamp(
store: BlobStore,
root_stamp: FileStamp,
) -> SnapshotBuilder
pub fn with_root_stamp( store: BlobStore, root_stamp: FileStamp, ) -> SnapshotBuilder
Start a host snapshot whose root identity was captured without following links.
Panics
Panics if root_stamp does not describe a directory. Host adapters construct
this value directly from an already-open directory capability.
Sourcepub fn add_directory(
&mut self,
path: VPath,
mode: u32,
) -> Result<&mut SnapshotBuilder, SnapshotError>
pub fn add_directory( &mut self, path: VPath, mode: u32, ) -> Result<&mut SnapshotBuilder, SnapshotError>
Add a directory to the immutable manifest.
Errors
Returns SnapshotError::DuplicatePath when path already exists.
Sourcepub fn add_stamped_directory(
&mut self,
path: VPath,
stamp: FileStamp,
) -> Result<&mut SnapshotBuilder, SnapshotError>
pub fn add_stamped_directory( &mut self, path: VPath, stamp: FileStamp, ) -> Result<&mut SnapshotBuilder, SnapshotError>
Add a host directory while retaining its race-detection identity.
Errors
Returns an error for duplicate paths or a non-directory stamp.
Sourcepub fn add_file(
&mut self,
path: VPath,
bytes: &[u8],
mode: u32,
) -> Result<&mut SnapshotBuilder, SnapshotError>
pub fn add_file( &mut self, path: VPath, bytes: &[u8], mode: u32, ) -> Result<&mut SnapshotBuilder, SnapshotError>
Add and content-address a regular file.
Errors
Returns an error for duplicate paths or blob-store failures.
Sourcepub fn add_symlink(
&mut self,
path: VPath,
target: &[u8],
mode: u32,
) -> Result<&mut SnapshotBuilder, SnapshotError>
pub fn add_symlink( &mut self, path: VPath, target: &[u8], mode: u32, ) -> Result<&mut SnapshotBuilder, SnapshotError>
Add an opaque symbolic link without following its target.
Errors
Returns an error for duplicate paths or blob-store failures.
Sourcepub fn add_lazy<L>(
&mut self,
path: VPath,
stamp: FileStamp,
loader: L,
) -> Result<&mut SnapshotBuilder, SnapshotError>where
L: ContentLoader + 'static,
pub fn add_lazy<L>(
&mut self,
path: VPath,
stamp: FileStamp,
loader: L,
) -> Result<&mut SnapshotBuilder, SnapshotError>where
L: ContentLoader + 'static,
Add a file or symlink whose content will be captured on first read.
Errors
Returns an error for duplicate paths or a directory stamp.
Sourcepub fn build(self) -> Result<BaseSnapshot, SnapshotError>
pub fn build(self) -> Result<BaseSnapshot, SnapshotError>
Validate parent relationships and freeze the snapshot.
Errors
Returns an error when a parent is absent or not a directory.