ExecutionBudget

Type Alias ExecutionBudget 

pub type ExecutionBudget = ExecutionLimits;
Request-scoped resource caps enforced by the Monty/VFS adapter.

Aliased Type

pub struct ExecutionBudget {
Show 13 fields pub max_program_bytes: usize, pub max_duration: Duration, pub max_recursion_depth: usize, pub max_memory_bytes: usize, pub max_os_calls: u64, pub max_read_bytes: u64, pub max_write_bytes: u64, pub max_io_call_bytes: usize, pub max_path_bytes: usize, pub max_directory_entries: u64, pub max_output_bytes: usize, pub max_result_bytes: usize, pub max_exception_bytes: usize,
}

Fields

max_program_bytes: usize

Maximum UTF-8 bytes accepted as one program.

max_duration: Duration

Cumulative time Monty may spend executing bytecode.

max_recursion_depth: usize

Maximum Python call-stack depth.

max_memory_bytes: usize

Maximum interpreter heap bytes enforced by the supervised worker allocator. The process-local correctness harness cannot install a per-call global allocator.

max_os_calls: u64

Maximum typed OS calls and high-level VSH tool calls serviced by the host adapter.

max_read_bytes: u64

Maximum cumulative bytes materialized by read and append operations.

max_write_bytes: u64

Maximum cumulative bytes submitted by write and append operations.

max_io_call_bytes: usize

Maximum payload bytes materialized by one typed read or write call.

max_path_bytes: usize

Maximum UTF-8 bytes accepted in one Monty-visible path.

max_directory_entries: u64

Maximum cumulative directory entries returned to Monty.

max_output_bytes: usize

Maximum UTF-8 bytes retained from print() output.

max_result_bytes: usize

Maximum deep host footprint of the returned Monty value.

max_exception_bytes: usize

Maximum retained exception message, traceback and structured payload bytes.